#
# spec file for package apparmor-parser (Version 2.1.1)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           apparmor-parser
%if ! %{?distro:1}0
%if %{?suse_version:1}0
  %define distro suse
%endif
%if %{?fedora_version:1}0
  %define distro redhat
%endif
%endif
%if ! %{?distro:1}0
  %define distro suse
%endif
Summary:        AppArmor userlevel parser utility
Version:        2.1.1
Release:        0.8.1
Group:          Productivity/Networking/Security
Source0:        %{name}-%{version}-1082.tar.gz
Source1:        series
Patch1:         apparmor-parser-regex-merge
Patch2:         apparmor-parser-tree-normalization-full
Patch3:         apparmor-parser-tree-normalization-loop
License:        GPL v2 or later
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://forge.novell.com/modules/xfmod/project/?apparmor
PreReq:         sed
%if %{distro} == "suse"
PreReq:         %{insserv_prereq} aaa_base
%endif
BuildRequires:  gcc-c++
Obsoletes:      subdomain_parser subdomain-parser
Obsoletes:      subdomain-parser-demo subdomain-parser-common subdomain-leaf-cert
Obsoletes:      libimnxcert
Provides:       subdomain_parser subdomain-parser
Provides:       subdomain-parser-demo subdomain-parser-common subdomain-leaf-cert
Provides:       libimnxcert
%define apparmor_bin_prefix /lib/apparmor
BuildRequires:  bison flex latex2html w3m
%if 0%{?suse_version} > 1020
BuildRequires:  texlive-latex
%else
BuildRequires:  te_latex
%endif

%description
The AppArmor Parser is a userlevel program that is used to load in
program profiles to the AppArmor Security kernel module.

This package is part of a suite of tools that used to be named
SubDomain.



Authors:
--------
    jjohansen@suse.de
    sbeattie@suse.de
    tonyj@suse.de

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
make clean all CFLAGS="${RPM_OPT_FLAGS}"
make techdoc.txt

%install
make install DESTDIR=${RPM_BUILD_ROOT} \
	     MANDIR=%{_mandir} \
	     DISTRO=%{distro} \
	     APPARMOR_BIN_PREFIX=${RPM_BUILD_ROOT}%{apparmor_bin_prefix}

%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc README COPYING.GPL
/sbin/apparmor_parser
%dir %attr(-, root, root) /etc/apparmor
%if %{distro} == "suse"
  /sbin/rcsubdomain
  /sbin/rcapparmor
  /etc/init.d/boot.apparmor
  /sbin/rcaaeventd
  /etc/init.d/aaeventd
%else
  /etc/init.d/apparmor
  /etc/init.d/aaeventd
%endif
%config(noreplace) /etc/apparmor/subdomain.conf
/var/lib/apparmor
%dir %attr(-, root, root) %{apparmor_bin_prefix}
%{apparmor_bin_prefix}/rc.apparmor.functions
%if 0%{?suse_version} <= 1010
# needed on sles
%dir %{_prefix}/share/locale/si
%dir %{_prefix}/share/locale/si/LC_MESSAGES
%endif
%{_prefix}/share/locale/*/*/apparmor-parser.mo
%doc %{_mandir}/man*/*

%pre
%if %{distro} == "redhat" || %{distro} == "rhel4"
if [ -f /etc/init.d/subdomain ] ; then
  chkconfig --del subdomain
fi
%endif

%post
%if %{distro} == "suse"
  # SUSE uses insserv
  # For package renaming from subdomain -> apparmor
  # we check the existence of the AppArmor 1.1 and 
  # AppArmor 1.2 based init script to help determine 
  # whether  we are upgrading
  SUBDOMAIN_PARSER_INSTALLED="no"
  if test -e /etc/init.d/boot.subdomain -o -e /etc/init.d/subdomain; then
    SUBDOMAIN_PARSER_INSTALLED="yes"
  fi
  if  test "$1" == 1  -a $SUBDOMAIN_PARSER_INSTALLED = "no"; then
    %{insserv_force_if_yast boot.apparmor}
  elif test -e /etc/rc.d/boot.d/S??boot.subdomain  -o \
            -e /etc/rc.d/boot.d/S??boot.apparmor  -o \
            -e /etc/rc.d/rc3.d/S??subdomain ; then
    %{insserv_force_if_yast boot.apparmor}
  else
    %{fillup_and_insserv -f boot.apparmor}
  fi
%endif
%if %{distro} == "redhat" || %{distro} == "rhel4"
  chkconfig --add apparmor
%endif
%if %{distro} == "slackware"
  if grep -qs "# BEGIN rc.subdomain INSERTION" /etc/rc.d/rc.M ; then true ; else
    %{apparmor_bin_prefix}/install/frob_slack_rc --init
  fi
  if grep -qs "# BEGIN rc.subdomain INSERTION" /etc/rc.d/rc.K ; then true ; else
    %{apparmor_bin_prefix}/install/frob_slack_rc --shutdown
  fi
%endif

%preun
if [ "$1" = 0 ] ; then
%if %{distro} == "suse"
  %{stop_on_removal aaeventd}
  %{stop_on_removal boot.apparmor}
%endif
%if %{distro} == "redhat" || %{distro} == "rhel4"
  chkconfig --del aaeventd
  chkconfig --del apparmor
%endif
fi

%postun
%if %{distro} == "suse"
  %restart_on_update aaeventd boot.apparmor
  %{insserv_cleanup}
%endif

%changelog
* Fri Aug 13 2010 lchiquitto@suse.de
- fix a bug that would prevent trees from being fully normalized
  (bnc#622700)
* Wed Feb 11 2009 jeffm@suse.de
- fix for excessive memory use while parsing
  certain profiles (bnc#421077)
* Fri Jan 16 2009 lrupp@suse.de
- restart aaeventd and boot.apparmor on update
* Thu Jan 17 2008 jjohansen@suse.de
  Fix parser to be able to load policy for multiple versions of AppArmor.
  2_0 AppArmor before match string (pcre)
  2_0 AppArmor with match string (pcre & dfa)
  2_1 AppArmor with match string (dfa)
  - includes SLES10-SP2 variant with 2_0 semantics
* Mon Oct  1 2007 jjohansen@suse.de
- Basic change_profile testcases, basic network rules testcases, testcases
  around carat symbols and commas in file rules, and basic permission
  modes first testcases from jjohansen@suse.de.
* Mon Oct  1 2007 jjohansen@suse.de
- lock mode bit tests from jjohansen@suse.de
- Also, make 'check' toplevel target be an alias for 'tests'
* Mon Oct  1 2007 jjohansen@suse.de
- Append testcases
* Fri Aug 31 2007 sbeattie@suse.de
- only run apparmor initscript at boot level (#286749)
* Tue Aug 21 2007 ro@suse.de
- split off apparmor-docs to its own specfile to keep it noarch
* Mon Aug 20 2007 sbeattie@suse.de
- disabled aaeventd initscript before uninstalling [#301418]
- Fix double free bug
* Mon Aug  6 2007 dreynolds@suse.de
- Added updated translations
- Fix turkish localization problem - patch
  from S.Çağlar Onur <caglar@pardus.org.tr>
- Updated makefile to handle AF_RXRPC protocol from socket.h
* Sat Jul 28 2007 sbeattie@suse.de
- Allow inverted character classes in unquoted pathnames
- Fix return code propogation in initscripts
- Add change_profile support
- Add basic network mediation
- Add mediation modes for append-only and locks
- Allow reverse ordered file permission rules
* Sat Apr 21 2007 aj@suse.de
- Use texlive for building.
* Thu Apr 12 2007 sbeattie@suse.de
- Add manpages to package
- Add apparmor-docs as subpackage
- Add techdoc to docs package
- Fix initscript to support apparmor as builtin
- Translation updates
* Sat Mar 31 2007 agruen@suse.de
- Update to version 2.0.2: DFA based kernel module.
* Thu Mar 29 2007 coolo@suse.de
- BuildRequire flex and bison
* Mon Nov 20 2006 dreynolds@suse.de
-  More translation updates
* Mon Nov 20 2006 dreynolds@suse.de
- Updates from the translation team
* Tue Nov 14 2006 sbeattie@suse.de
- fix rc.aaeventd to depend on apparmor, not boot.apparmor (#214293)
* Thu Nov  9 2006 sbeattie@suse.de
- Add audit_write and audit_control capabilities (#218961)
  (jjohansen@suse.de)
- pull translation updates from lcn (ddrewelow@suse.de)
- Use kernel's capability defines rather than libcap
- /lib/lsb/init-functions provides killproc(), use it instead.
* Sat Oct 28 2006 olh@suse.de
- boot.apparmor should start after boot.localfs (#215156)
* Sun Oct 15 2006 sbeattie@suse.de
- add support for #include'ing directories
- remove /subdomain (#160020)
- updated translation files (from SLE10)
* Fri Jul 28 2006 olh@suse.de
- make boot.localfs optional in boot.apparmor (#181972)
* Mon Jun  5 2006 sbeattie@suse.de
- Add support for 'm' flag (mmap w/PROT_EXEC permission) (#175388)
- Add Px and Ux flags to indicate to ld.so that sensitive environemnt
  variables should be filtered on exec() (#172061) The m, Px, and Ux
  flags are added in such a way that apparmor modules without
  corresponding support will just ignore them.
- Fix segv if profiles directory does not exist (#160330)
- Fix aaeventd initscript description (#172961)
- Add check to verify module supports pcre
- Add regression tests and run on every build
- Other minor fixups
* Fri May 26 2006 schwab@suse.de
- Don't strip binaries.
* Mon Apr  3 2006 dreynolds@suse.de
- Fix upgrade problems from sles9/sl10.0 (#156990)
* Mon Mar 27 2006 jmichael@suse.de
- Split aaeventd startup into its own init script so we don't start
  daemons while in the "boot" runlevel (#158613)
- Obsoleted libimnxcert (#157450)
* Mon Feb 13 2006 dreynolds@suse.de
- sbeattie@suse.de changes...
- Filter multiple slashes and trailing slashes in pathnames
- Use RPM_OPT_FLAGS
- A few s/SubDomain/AppArmor/ fixups in error messages
* Mon Feb  6 2006 sbeattie@suse.de
- Fix one last issue in initscript handling of whitespace (#141288)
- Add libcap-devel dependency for newer SUSE distros
- Fix shutting down aa-eventd
- Add option to enable/disable aa-eventd (#145465)
- Disable owlsm warning if module doesn't support it (#146470)
* Sun Jan 29 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 29 2006 sbeattie@suse.de
- s/none/securityfs/ in the initscript (#143372)
- add support for if {} else if {}
- rename initscript to rc.apparmor
- support /etc/apparmor.d
- add buildrequires on libcap-devel
- (dreynolds) Updated rc.subdomain.functions to reference newly named event daemon aa-eventd
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 sbeattie@suse.de
- convert to insserv macros, reenable apparmor by default (#143372)
- add prereq on aaa_base (#143372)
- remove initscript dependency on boot.ldconfig
- Don't edit fstab on newer suse releases (#143402)
- Add build dependency on libcap-devel
* Tue Jan 17 2006 dreynolds@suse.de
- Removed calls to inssrv to prevent the boot.subdomain service from being enabled by default.
* Sat Jan 14 2006 sbeattie@suse.de
- Add support for giving a filename on the parser command line
- Some refactoring of code in prep for variable support.
- Add svn repo to tarball
- Rename service provided by initscript to apparmor
- Initial set variable support
- Restructure global policy list
- Fix leaks found by valgrind
- Restructure hats within profiles, detect duplicate hats
- Add basic conditional statement support
- Fix debug mode to not attempt to load policy
- Add svn repo number to tarball name
* Fri Dec  9 2005 sbeattie@suse.de
-  Fix references to old package name in .po files
* Thu Dec  8 2005 sbeattie@suse.de
- rename subdomain-parser package to apparmor-parser
- Relicense package to GPL for open source release
- Reset version to 2.0-1
- add support for securityfs in initscript and parser
